"""AssemblyCompoundStabilityAnalysis"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_property_get,
)

from mastapy._private._internal import constructor, conversion, utility
from mastapy._private.system_model.analyses_and_results.stability_analyses.compound import (
    _4209,
)

_ASSEMBLY_COMPOUND_STABILITY_ANALYSIS = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.StabilityAnalyses.Compound",
    "AssemblyCompoundStabilityAnalysis",
)

if TYPE_CHECKING:
    from typing import Any, List, Type, TypeVar

    from mastapy._private.system_model.analyses_and_results import _2944
    from mastapy._private.system_model.analyses_and_results.analysis_cases import (
        _7941,
        _7944,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses import (
        _4080,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound import (
        _4217,
        _4219,
        _4222,
        _4228,
        _4229,
        _4230,
        _4235,
        _4240,
        _4250,
        _4252,
        _4254,
        _4258,
        _4264,
        _4265,
        _4266,
        _4273,
        _4280,
        _4283,
        _4284,
        _4285,
        _4287,
        _4289,
        _4290,
        _4291,
        _4296,
        _4297,
        _4298,
        _4300,
        _4302,
        _4305,
        _4306,
        _4307,
        _4312,
        _4313,
        _4318,
        _4321,
        _4324,
        _4328,
        _4332,
        _4336,
        _4339,
    )
    from mastapy._private.system_model.part_model import _2703

    Self = TypeVar("Self", bound="AssemblyCompoundStabilityAnalysis")
    CastSelf = TypeVar(
        "CastSelf",
        bound="AssemblyCompoundStabilityAnalysis._Cast_AssemblyCompoundStabilityAnalysis",
    )


__docformat__ = "restructuredtext en"
__all__ = ("AssemblyCompoundStabilityAnalysis",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_AssemblyCompoundStabilityAnalysis:
    """Special nested class for casting AssemblyCompoundStabilityAnalysis to subclasses."""

    __parent__: "AssemblyCompoundStabilityAnalysis"

    @property
    def abstract_assembly_compound_stability_analysis(
        self: "CastSelf",
    ) -> "_4209.AbstractAssemblyCompoundStabilityAnalysis":
        return self.__parent__._cast(_4209.AbstractAssemblyCompoundStabilityAnalysis)

    @property
    def part_compound_stability_analysis(
        self: "CastSelf",
    ) -> "_4290.PartCompoundStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses.compound import (
            _4290,
        )

        return self.__parent__._cast(_4290.PartCompoundStabilityAnalysis)

    @property
    def part_compound_analysis(self: "CastSelf") -> "_7944.PartCompoundAnalysis":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7944,
        )

        return self.__parent__._cast(_7944.PartCompoundAnalysis)

    @property
    def design_entity_compound_analysis(
        self: "CastSelf",
    ) -> "_7941.DesignEntityCompoundAnalysis":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7941,
        )

        return self.__parent__._cast(_7941.DesignEntityCompoundAnalysis)

    @property
    def design_entity_analysis(self: "CastSelf") -> "_2944.DesignEntityAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2944

        return self.__parent__._cast(_2944.DesignEntityAnalysis)

    @property
    def root_assembly_compound_stability_analysis(
        self: "CastSelf",
    ) -> "_4305.RootAssemblyCompoundStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses.compound import (
            _4305,
        )

        return self.__parent__._cast(_4305.RootAssemblyCompoundStabilityAnalysis)

    @property
    def assembly_compound_stability_analysis(
        self: "CastSelf",
    ) -> "AssemblyCompoundStabilityAnalysis":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class AssemblyCompoundStabilityAnalysis(
    _4209.AbstractAssemblyCompoundStabilityAnalysis
):
    """AssemblyCompoundStabilityAnalysis

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _ASSEMBLY_COMPOUND_STABILITY_ANALYSIS

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def component_design(self: "Self") -> "_2703.Assembly":
        """mastapy.system_model.part_model.Assembly

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ComponentDesign")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def assembly_design(self: "Self") -> "_2703.Assembly":
        """mastapy.system_model.part_model.Assembly

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "AssemblyDesign")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def assembly_analysis_cases_ready(
        self: "Self",
    ) -> "List[_4080.AssemblyStabilityAnalysis]":
        """List[mastapy.system_model.analyses_and_results.stability_analyses.AssemblyStabilityAnalysis]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "AssemblyAnalysisCasesReady")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def bearings(self: "Self") -> "List[_4217.BearingCompoundStabilityAnalysis]":
        """List[mastapy.system_model.analyses_and_results.stability_analyses.compound.BearingCompoundStabilityAnalysis]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "Bearings")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def belt_drives(self: "Self") -> "List[_4219.BeltDriveCompoundStabilityAnalysis]":
        """List[mastapy.system_model.analyses_and_results.stability_analyses.compound.BeltDriveCompoundStabilityAnalysis]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "BeltDrives")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def bevel_differential_gear_sets(
        self: "Self",
    ) -> "List[_4222.BevelDifferentialGearSetCompoundStabilityAnalysis]":
        """List[mastapy.system_model.analyses_and_results.stability_analyses.compound.BevelDifferentialGearSetCompoundStabilityAnalysis]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "BevelDifferentialGearSets")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def bolted_joints(
        self: "Self",
    ) -> "List[_4229.BoltedJointCompoundStabilityAnalysis]":
        """List[mastapy.system_model.analyses_and_results.stability_analyses.compound.BoltedJointCompoundStabilityAnalysis]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "BoltedJoints")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def bolts(self: "Self") -> "List[_4228.BoltCompoundStabilityAnalysis]":
        """List[mastapy.system_model.analyses_and_results.stability_analyses.compound.BoltCompoundStabilityAnalysis]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "Bolts")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def cv_ts(self: "Self") -> "List[_4250.CVTCompoundStabilityAnalysis]":
        """List[mastapy.system_model.analyses_and_results.stability_analyses.compound.CVTCompoundStabilityAnalysis]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "CVTs")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def clutches(self: "Self") -> "List[_4230.ClutchCompoundStabilityAnalysis]":
        """List[mastapy.system_model.analyses_and_results.stability_analyses.compound.ClutchCompoundStabilityAnalysis]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "Clutches")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def concept_couplings(
        self: "Self",
    ) -> "List[_4235.ConceptCouplingCompoundStabilityAnalysis]":
        """List[mastapy.system_model.analyses_and_results.stability_analyses.compound.ConceptCouplingCompoundStabilityAnalysis]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ConceptCouplings")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def concept_gear_sets(
        self: "Self",
    ) -> "List[_4240.ConceptGearSetCompoundStabilityAnalysis]":
        """List[mastapy.system_model.analyses_and_results.stability_analyses.compound.ConceptGearSetCompoundStabilityAnalysis]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ConceptGearSets")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def cycloidal_assemblies(
        self: "Self",
    ) -> "List[_4252.CycloidalAssemblyCompoundStabilityAnalysis]":
        """List[mastapy.system_model.analyses_and_results.stability_analyses.compound.CycloidalAssemblyCompoundStabilityAnalysis]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "CycloidalAssemblies")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def cycloidal_discs(
        self: "Self",
    ) -> "List[_4254.CycloidalDiscCompoundStabilityAnalysis]":
        """List[mastapy.system_model.analyses_and_results.stability_analyses.compound.CycloidalDiscCompoundStabilityAnalysis]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "CycloidalDiscs")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def cylindrical_gear_sets(
        self: "Self",
    ) -> "List[_4258.CylindricalGearSetCompoundStabilityAnalysis]":
        """List[mastapy.system_model.analyses_and_results.stability_analyses.compound.CylindricalGearSetCompoundStabilityAnalysis]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "CylindricalGearSets")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def fe_parts(self: "Self") -> "List[_4265.FEPartCompoundStabilityAnalysis]":
        """List[mastapy.system_model.analyses_and_results.stability_analyses.compound.FEPartCompoundStabilityAnalysis]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "FEParts")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def face_gear_sets(
        self: "Self",
    ) -> "List[_4264.FaceGearSetCompoundStabilityAnalysis]":
        """List[mastapy.system_model.analyses_and_results.stability_analyses.compound.FaceGearSetCompoundStabilityAnalysis]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "FaceGearSets")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def flexible_pin_assemblies(
        self: "Self",
    ) -> "List[_4266.FlexiblePinAssemblyCompoundStabilityAnalysis]":
        """List[mastapy.system_model.analyses_and_results.stability_analyses.compound.FlexiblePinAssemblyCompoundStabilityAnalysis]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "FlexiblePinAssemblies")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def hypoid_gear_sets(
        self: "Self",
    ) -> "List[_4273.HypoidGearSetCompoundStabilityAnalysis]":
        """List[mastapy.system_model.analyses_and_results.stability_analyses.compound.HypoidGearSetCompoundStabilityAnalysis]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "HypoidGearSets")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def klingelnberg_cyclo_palloid_hypoid_gear_sets(
        self: "Self",
    ) -> "List[_4280.KlingelnbergCycloPalloidHypoidGearSetCompoundStabilityAnalysis]":
        """List[mastapy.system_model.analyses_and_results.stability_analyses.compound.KlingelnbergCycloPalloidHypoidGearSetCompoundStabilityAnalysis]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "KlingelnbergCycloPalloidHypoidGearSets"
        )

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def klingelnberg_cyclo_palloid_spiral_bevel_gear_sets(
        self: "Self",
    ) -> "List[_4283.KlingelnbergCycloPalloidSpiralBevelGearSetCompoundStabilityAnalysis]":
        """List[mastapy.system_model.analyses_and_results.stability_analyses.compound.KlingelnbergCycloPalloidSpiralBevelGearSetCompoundStabilityAnalysis]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "KlingelnbergCycloPalloidSpiralBevelGearSets"
        )

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def mass_discs(self: "Self") -> "List[_4284.MassDiscCompoundStabilityAnalysis]":
        """List[mastapy.system_model.analyses_and_results.stability_analyses.compound.MassDiscCompoundStabilityAnalysis]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "MassDiscs")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def measurement_components(
        self: "Self",
    ) -> "List[_4285.MeasurementComponentCompoundStabilityAnalysis]":
        """List[mastapy.system_model.analyses_and_results.stability_analyses.compound.MeasurementComponentCompoundStabilityAnalysis]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "MeasurementComponents")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def microphones(self: "Self") -> "List[_4287.MicrophoneCompoundStabilityAnalysis]":
        """List[mastapy.system_model.analyses_and_results.stability_analyses.compound.MicrophoneCompoundStabilityAnalysis]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "Microphones")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def oil_seals(self: "Self") -> "List[_4289.OilSealCompoundStabilityAnalysis]":
        """List[mastapy.system_model.analyses_and_results.stability_analyses.compound.OilSealCompoundStabilityAnalysis]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "OilSeals")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def part_to_part_shear_couplings(
        self: "Self",
    ) -> "List[_4291.PartToPartShearCouplingCompoundStabilityAnalysis]":
        """List[mastapy.system_model.analyses_and_results.stability_analyses.compound.PartToPartShearCouplingCompoundStabilityAnalysis]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "PartToPartShearCouplings")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def planet_carriers(
        self: "Self",
    ) -> "List[_4296.PlanetCarrierCompoundStabilityAnalysis]":
        """List[mastapy.system_model.analyses_and_results.stability_analyses.compound.PlanetCarrierCompoundStabilityAnalysis]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "PlanetCarriers")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def point_loads(self: "Self") -> "List[_4297.PointLoadCompoundStabilityAnalysis]":
        """List[mastapy.system_model.analyses_and_results.stability_analyses.compound.PointLoadCompoundStabilityAnalysis]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "PointLoads")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def power_loads(self: "Self") -> "List[_4298.PowerLoadCompoundStabilityAnalysis]":
        """List[mastapy.system_model.analyses_and_results.stability_analyses.compound.PowerLoadCompoundStabilityAnalysis]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "PowerLoads")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def ring_pins(self: "Self") -> "List[_4300.RingPinsCompoundStabilityAnalysis]":
        """List[mastapy.system_model.analyses_and_results.stability_analyses.compound.RingPinsCompoundStabilityAnalysis]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "RingPins")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def rolling_ring_assemblies(
        self: "Self",
    ) -> "List[_4302.RollingRingAssemblyCompoundStabilityAnalysis]":
        """List[mastapy.system_model.analyses_and_results.stability_analyses.compound.RollingRingAssemblyCompoundStabilityAnalysis]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "RollingRingAssemblies")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def shaft_hub_connections(
        self: "Self",
    ) -> "List[_4307.ShaftHubConnectionCompoundStabilityAnalysis]":
        """List[mastapy.system_model.analyses_and_results.stability_analyses.compound.ShaftHubConnectionCompoundStabilityAnalysis]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ShaftHubConnections")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def shafts(self: "Self") -> "List[_4306.ShaftCompoundStabilityAnalysis]":
        """List[mastapy.system_model.analyses_and_results.stability_analyses.compound.ShaftCompoundStabilityAnalysis]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "Shafts")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def spiral_bevel_gear_sets(
        self: "Self",
    ) -> "List[_4312.SpiralBevelGearSetCompoundStabilityAnalysis]":
        """List[mastapy.system_model.analyses_and_results.stability_analyses.compound.SpiralBevelGearSetCompoundStabilityAnalysis]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "SpiralBevelGearSets")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def spring_dampers(
        self: "Self",
    ) -> "List[_4313.SpringDamperCompoundStabilityAnalysis]":
        """List[mastapy.system_model.analyses_and_results.stability_analyses.compound.SpringDamperCompoundStabilityAnalysis]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "SpringDampers")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def straight_bevel_diff_gear_sets(
        self: "Self",
    ) -> "List[_4318.StraightBevelDiffGearSetCompoundStabilityAnalysis]":
        """List[mastapy.system_model.analyses_and_results.stability_analyses.compound.StraightBevelDiffGearSetCompoundStabilityAnalysis]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "StraightBevelDiffGearSets")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def straight_bevel_gear_sets(
        self: "Self",
    ) -> "List[_4321.StraightBevelGearSetCompoundStabilityAnalysis]":
        """List[mastapy.system_model.analyses_and_results.stability_analyses.compound.StraightBevelGearSetCompoundStabilityAnalysis]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "StraightBevelGearSets")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def synchronisers(
        self: "Self",
    ) -> "List[_4324.SynchroniserCompoundStabilityAnalysis]":
        """List[mastapy.system_model.analyses_and_results.stability_analyses.compound.SynchroniserCompoundStabilityAnalysis]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "Synchronisers")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def torque_converters(
        self: "Self",
    ) -> "List[_4328.TorqueConverterCompoundStabilityAnalysis]":
        """List[mastapy.system_model.analyses_and_results.stability_analyses.compound.TorqueConverterCompoundStabilityAnalysis]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "TorqueConverters")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def unbalanced_masses(
        self: "Self",
    ) -> "List[_4332.UnbalancedMassCompoundStabilityAnalysis]":
        """List[mastapy.system_model.analyses_and_results.stability_analyses.compound.UnbalancedMassCompoundStabilityAnalysis]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "UnbalancedMasses")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def worm_gear_sets(
        self: "Self",
    ) -> "List[_4336.WormGearSetCompoundStabilityAnalysis]":
        """List[mastapy.system_model.analyses_and_results.stability_analyses.compound.WormGearSetCompoundStabilityAnalysis]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "WormGearSets")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def zerol_bevel_gear_sets(
        self: "Self",
    ) -> "List[_4339.ZerolBevelGearSetCompoundStabilityAnalysis]":
        """List[mastapy.system_model.analyses_and_results.stability_analyses.compound.ZerolBevelGearSetCompoundStabilityAnalysis]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ZerolBevelGearSets")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def assembly_analysis_cases(
        self: "Self",
    ) -> "List[_4080.AssemblyStabilityAnalysis]":
        """List[mastapy.system_model.analyses_and_results.stability_analyses.AssemblyStabilityAnalysis]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "AssemblyAnalysisCases")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def cast_to(self: "Self") -> "_Cast_AssemblyCompoundStabilityAnalysis":
        """Cast to another type.

        Returns:
            _Cast_AssemblyCompoundStabilityAnalysis
        """
        return _Cast_AssemblyCompoundStabilityAnalysis(self)



"""ConceptGearMeshAdvancedSystemDeflection"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_property_get,
)

from mastapy._private._internal import constructor, conversion, utility
from mastapy._private.system_model.analyses_and_results.advanced_system_deflections import (
    _7510,
)

_CONCEPT_GEAR_MESH_ADVANCED_SYSTEM_DEFLECTION = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.AdvancedSystemDeflections",
    "ConceptGearMeshAdvancedSystemDeflection",
)

if TYPE_CHECKING:
    from typing import Any, List, Type, TypeVar

    from mastapy._private.gears.rating.concept import _663
    from mastapy._private.system_model.analyses_and_results import _2942, _2944, _2946
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections import (
        _7484,
        _7516,
    )
    from mastapy._private.system_model.analyses_and_results.analysis_cases import (
        _7936,
        _7939,
    )
    from mastapy._private.system_model.analyses_and_results.static_loads import _7765
    from mastapy._private.system_model.analyses_and_results.system_deflections import (
        _3013,
    )
    from mastapy._private.system_model.connections_and_sockets.gears import _2565

    Self = TypeVar("Self", bound="ConceptGearMeshAdvancedSystemDeflection")
    CastSelf = TypeVar(
        "CastSelf",
        bound="ConceptGearMeshAdvancedSystemDeflection._Cast_ConceptGearMeshAdvancedSystemDeflection",
    )


__docformat__ = "restructuredtext en"
__all__ = ("ConceptGearMeshAdvancedSystemDeflection",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_ConceptGearMeshAdvancedSystemDeflection:
    """Special nested class for casting ConceptGearMeshAdvancedSystemDeflection to subclasses."""

    __parent__: "ConceptGearMeshAdvancedSystemDeflection"

    @property
    def gear_mesh_advanced_system_deflection(
        self: "CastSelf",
    ) -> "_7510.GearMeshAdvancedSystemDeflection":
        return self.__parent__._cast(_7510.GearMeshAdvancedSystemDeflection)

    @property
    def inter_mountable_component_connection_advanced_system_deflection(
        self: "CastSelf",
    ) -> "_7516.InterMountableComponentConnectionAdvancedSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.advanced_system_deflections import (
            _7516,
        )

        return self.__parent__._cast(
            _7516.InterMountableComponentConnectionAdvancedSystemDeflection
        )

    @property
    def connection_advanced_system_deflection(
        self: "CastSelf",
    ) -> "_7484.ConnectionAdvancedSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.advanced_system_deflections import (
            _7484,
        )

        return self.__parent__._cast(_7484.ConnectionAdvancedSystemDeflection)

    @property
    def connection_static_load_analysis_case(
        self: "CastSelf",
    ) -> "_7939.ConnectionStaticLoadAnalysisCase":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7939,
        )

        return self.__parent__._cast(_7939.ConnectionStaticLoadAnalysisCase)

    @property
    def connection_analysis_case(self: "CastSelf") -> "_7936.ConnectionAnalysisCase":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7936,
        )

        return self.__parent__._cast(_7936.ConnectionAnalysisCase)

    @property
    def connection_analysis(self: "CastSelf") -> "_2942.ConnectionAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2942

        return self.__parent__._cast(_2942.ConnectionAnalysis)

    @property
    def design_entity_single_context_analysis(
        self: "CastSelf",
    ) -> "_2946.DesignEntitySingleContextAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2946

        return self.__parent__._cast(_2946.DesignEntitySingleContextAnalysis)

    @property
    def design_entity_analysis(self: "CastSelf") -> "_2944.DesignEntityAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2944

        return self.__parent__._cast(_2944.DesignEntityAnalysis)

    @property
    def concept_gear_mesh_advanced_system_deflection(
        self: "CastSelf",
    ) -> "ConceptGearMeshAdvancedSystemDeflection":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class ConceptGearMeshAdvancedSystemDeflection(_7510.GearMeshAdvancedSystemDeflection):
    """ConceptGearMeshAdvancedSystemDeflection

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _CONCEPT_GEAR_MESH_ADVANCED_SYSTEM_DEFLECTION

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def component_detailed_analysis(self: "Self") -> "_663.ConceptGearMeshRating":
        """mastapy.gears.rating.concept.ConceptGearMeshRating

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ComponentDetailedAnalysis")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def connection_design(self: "Self") -> "_2565.ConceptGearMesh":
        """mastapy.system_model.connections_and_sockets.gears.ConceptGearMesh

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ConnectionDesign")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def connection_load_case(self: "Self") -> "_7765.ConceptGearMeshLoadCase":
        """mastapy.system_model.analyses_and_results.static_loads.ConceptGearMeshLoadCase

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ConnectionLoadCase")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def connection_system_deflection_results(
        self: "Self",
    ) -> "List[_3013.ConceptGearMeshSystemDeflection]":
        """List[mastapy.system_model.analyses_and_results.system_deflections.ConceptGearMeshSystemDeflection]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ConnectionSystemDeflectionResults")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def cast_to(self: "Self") -> "_Cast_ConceptGearMeshAdvancedSystemDeflection":
        """Cast to another type.

        Returns:
            _Cast_ConceptGearMeshAdvancedSystemDeflection
        """
        return _Cast_ConceptGearMeshAdvancedSystemDeflection(self)



"""Subpackage."""

from typing import TYPE_CHECKING as __tc

if __tc:
    from mastapy._private.fe_tools.vis_tools_global.vis_tools_global_enums._1381 import (
        BeamSectionType,
    )
    from mastapy._private.fe_tools.vis_tools_global.vis_tools_global_enums._1382 import (
        ContactPairConstrainedSurfaceType,
    )
    from mastapy._private.fe_tools.vis_tools_global.vis_tools_global_enums._1383 import (
        ContactPairReferenceSurfaceType,
    )
    from mastapy._private.fe_tools.vis_tools_global.vis_tools_global_enums._1384 import (
        ElementPropertiesShellIntegrationRule,
    )
    from mastapy._private.fe_tools.vis_tools_global.vis_tools_global_enums._1385 import (
        ElementPropertiesShellWallType,
    )
else:
    import sys as __sys

    from lazy_imports import LazyImporter as __LazyImporter

    __import_structure = {
        "_private.fe_tools.vis_tools_global.vis_tools_global_enums._1381": [
            "BeamSectionType"
        ],
        "_private.fe_tools.vis_tools_global.vis_tools_global_enums._1382": [
            "ContactPairConstrainedSurfaceType"
        ],
        "_private.fe_tools.vis_tools_global.vis_tools_global_enums._1383": [
            "ContactPairReferenceSurfaceType"
        ],
        "_private.fe_tools.vis_tools_global.vis_tools_global_enums._1384": [
            "ElementPropertiesShellIntegrationRule"
        ],
        "_private.fe_tools.vis_tools_global.vis_tools_global_enums._1385": [
            "ElementPropertiesShellWallType"
        ],
    }

    __sys.modules[__name__] = __LazyImporter(
        "mastapy",
        globals()["__file__"],
        __import_structure,
    )

__all__ = (
    "BeamSectionType",
    "ContactPairConstrainedSurfaceType",
    "ContactPairReferenceSurfaceType",
    "ElementPropertiesShellIntegrationRule",
    "ElementPropertiesShellWallType",
)



"""ShaftSectionEndDamageResults"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_method_call,
    pythonnet_property_get,
    pythonnet_property_set,
)
from mastapy._private._internal.type_enforcement import enforce_parameter_types
from mastapy._private._math.vector_3d import Vector3D

from mastapy._private import _0
from mastapy._private._internal import constructor, conversion, utility

_SHAFT_SECTION_END_DAMAGE_RESULTS = python_net_import(
    "SMT.MastaAPI.Shafts", "ShaftSectionEndDamageResults"
)

if TYPE_CHECKING:
    from typing import Any, List, Type, TypeVar

    from mastapy._private._internal.typing import PathLike

    from mastapy._private.materials import _383
    from mastapy._private.nodal_analysis import _91
    from mastapy._private.shafts import _16, _17, _29, _47

    Self = TypeVar("Self", bound="ShaftSectionEndDamageResults")
    CastSelf = TypeVar(
        "CastSelf",
        bound="ShaftSectionEndDamageResults._Cast_ShaftSectionEndDamageResults",
    )


__docformat__ = "restructuredtext en"
__all__ = ("ShaftSectionEndDamageResults",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_ShaftSectionEndDamageResults:
    """Special nested class for casting ShaftSectionEndDamageResults to subclasses."""

    __parent__: "ShaftSectionEndDamageResults"

    @property
    def shaft_section_end_damage_results(
        self: "CastSelf",
    ) -> "ShaftSectionEndDamageResults":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class ShaftSectionEndDamageResults(_0.APIBase):
    """ShaftSectionEndDamageResults

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _SHAFT_SECTION_END_DAMAGE_RESULTS

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def displacement_angular(self: "Self") -> "Vector3D":
        """Vector3D

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "DisplacementAngular")

        if temp is None:
            return None

        value = conversion.pn_to_mp_vector3d(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def displacement_axial(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "DisplacementAxial")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def displacement_linear(self: "Self") -> "Vector3D":
        """Vector3D

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "DisplacementLinear")

        if temp is None:
            return None

        value = conversion.pn_to_mp_vector3d(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def displacement_radial_magnitude(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "DisplacementRadialMagnitude")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def displacement_radial_tilt_magnitude(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "DisplacementRadialTiltMagnitude")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def displacement_twist(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "DisplacementTwist")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def equivalent_alternating_stress(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "EquivalentAlternatingStress")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def fatigue_damage(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "FatigueDamage")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def fatigue_safety_factor(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "FatigueSafetyFactor")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def fatigue_safety_factor_for_infinite_life(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "FatigueSafetyFactorForInfiniteLife"
        )

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def force_angular(self: "Self") -> "Vector3D":
        """Vector3D

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ForceAngular")

        if temp is None:
            return None

        value = conversion.pn_to_mp_vector3d(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def force_axial(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ForceAxial")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def force_linear(self: "Self") -> "Vector3D":
        """Vector3D

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ForceLinear")

        if temp is None:
            return None

        value = conversion.pn_to_mp_vector3d(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def force_radial_magnitude(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ForceRadialMagnitude")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def force_torque(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ForceTorque")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def offset(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "Offset")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def outer_diameter_to_achieve_fatigue_safety_factor_requirement(
        self: "Self",
    ) -> "float":
        """float"""
        temp = pythonnet_property_get(
            self.wrapped, "OuterDiameterToAchieveFatigueSafetyFactorRequirement"
        )

        if temp is None:
            return 0.0

        return temp

    @outer_diameter_to_achieve_fatigue_safety_factor_requirement.setter
    @exception_bridge
    @enforce_parameter_types
    def outer_diameter_to_achieve_fatigue_safety_factor_requirement(
        self: "Self", value: "float"
    ) -> None:
        pythonnet_property_set(
            self.wrapped,
            "OuterDiameterToAchieveFatigueSafetyFactorRequirement",
            float(value) if value is not None else 0.0,
        )

    @property
    @exception_bridge
    def outer_radius_to_achieve_shaft_fatigue_safety_factor_requirement(
        self: "Self",
    ) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "OuterRadiusToAchieveShaftFatigueSafetyFactorRequirement"
        )

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def reliability_for_infinite_life(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ReliabilityForInfiniteLife")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def section_end(self: "Self") -> "_91.SectionEnd":
        """mastapy.nodal_analysis.SectionEnd

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "SectionEnd")

        if temp is None:
            return None

        value = conversion.pn_to_mp_enum(temp, "SMT.MastaAPI.NodalAnalysis.SectionEnd")

        if value is None:
            return None

        return constructor.new_from_mastapy(
            "mastapy._private.nodal_analysis._91", "SectionEnd"
        )(value)

    @property
    @exception_bridge
    def shaft_reliability(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ShaftReliability")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def static_safety_factor(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "StaticSafetyFactor")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def total_number_of_cycles(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "TotalNumberOfCycles")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def din743201212_component_fatigue_limit_under_reversed_stress_sigma_zd_wk_sigma_bwk_tau_twk(
        self: "Self",
    ) -> "_47.StressMeasurementShaftAxialBendingTorsionalComponentValues":
        """mastapy.shafts.StressMeasurementShaftAxialBendingTorsionalComponentValues

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped,
            "DIN743201212ComponentFatigueLimitUnderReversedStressSigmaZdWKSigmaBWKTauTWK",
        )

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def din743201212_component_yield_point_sigma_zd_fk_sigma_bfk_tau_tfk(
        self: "Self",
    ) -> "_47.StressMeasurementShaftAxialBendingTorsionalComponentValues":
        """mastapy.shafts.StressMeasurementShaftAxialBendingTorsionalComponentValues

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "DIN743201212ComponentYieldPointSigmaZdFKSigmaBFKTauTFK"
        )

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def din743201212_influence_factor_for_mean_stress_sensitivity_psi_sigma_k_psi_tau_k(
        self: "Self",
    ) -> "_16.ShaftAxialBendingTorsionalComponentValues":
        """mastapy.shafts.ShaftAxialBendingTorsionalComponentValues

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped,
            "DIN743201212InfluenceFactorForMeanStressSensitivityPsiSigmaKPsiTauK",
        )

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def fkm_guideline_6th_edition_2012_cyclic_degree_of_utilization_for_finite_life(
        self: "Self",
    ) -> "_17.ShaftAxialBendingXBendingYTorsionalComponentValues":
        """mastapy.shafts.ShaftAxialBendingXBendingYTorsionalComponentValues

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped,
            "FKMGuideline6thEdition2012CyclicDegreeOfUtilizationForFiniteLife",
        )

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def fkm_guideline_6th_edition_2012_cyclic_degree_of_utilization_for_infinite_life(
        self: "Self",
    ) -> "_17.ShaftAxialBendingXBendingYTorsionalComponentValues":
        """mastapy.shafts.ShaftAxialBendingXBendingYTorsionalComponentValues

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped,
            "FKMGuideline6thEdition2012CyclicDegreeOfUtilizationForInfiniteLife",
        )

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def sn_curve(self: "Self") -> "_383.SNCurve":
        """mastapy.materials.SNCurve

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "SNCurve")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def sn_curve_axial(self: "Self") -> "_383.SNCurve":
        """mastapy.materials.SNCurve

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "SNCurveAxial")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def sn_curve_bending_x(self: "Self") -> "_383.SNCurve":
        """mastapy.materials.SNCurve

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "SNCurveBendingX")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def sn_curve_bending_y(self: "Self") -> "_383.SNCurve":
        """mastapy.materials.SNCurve

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "SNCurveBendingY")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def sn_curve_torsional(self: "Self") -> "_383.SNCurve":
        """mastapy.materials.SNCurve

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "SNCurveTorsional")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def stress_concentration_factors(
        self: "Self",
    ) -> "_16.ShaftAxialBendingTorsionalComponentValues":
        """mastapy.shafts.ShaftAxialBendingTorsionalComponentValues

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "StressConcentrationFactors")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def din743201212_stress_amplitude_of_component_fatigue_strength_sigma_zd_adk_sigma_badk_tau_tadk(
        self: "Self",
    ) -> "List[_47.StressMeasurementShaftAxialBendingTorsionalComponentValues]":
        """List[mastapy.shafts.StressMeasurementShaftAxialBendingTorsionalComponentValues]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped,
            "DIN743201212StressAmplitudeOfComponentFatigueStrengthSigmaZdADKSigmaBADKTauTADK",
        )

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def stress_cycles(self: "Self") -> "List[_29.ShaftPointStressCycleReporting]":
        """List[mastapy.shafts.ShaftPointStressCycleReporting]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "StressCycles")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def report_names(self: "Self") -> "List[str]":
        """List[str]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ReportNames")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp, str)

        if value is None:
            return None

        return value

    @exception_bridge
    @enforce_parameter_types
    def output_default_report_to(self: "Self", file_path: "PathLike") -> None:
        """Method does not return.

        Args:
            file_path (PathLike)
        """
        file_path = str(file_path)
        pythonnet_method_call(self.wrapped, "OutputDefaultReportTo", file_path)

    @exception_bridge
    def get_default_report_with_encoded_images(self: "Self") -> "str":
        """str"""
        method_result = pythonnet_method_call(
            self.wrapped, "GetDefaultReportWithEncodedImages"
        )
        return method_result

    @exception_bridge
    @enforce_parameter_types
    def output_active_report_to(self: "Self", file_path: "PathLike") -> None:
        """Method does not return.

        Args:
            file_path (PathLike)
        """
        file_path = str(file_path)
        pythonnet_method_call(self.wrapped, "OutputActiveReportTo", file_path)

    @exception_bridge
    @enforce_parameter_types
    def output_active_report_as_text_to(self: "Self", file_path: "PathLike") -> None:
        """Method does not return.

        Args:
            file_path (PathLike)
        """
        file_path = str(file_path)
        pythonnet_method_call(self.wrapped, "OutputActiveReportAsTextTo", file_path)

    @exception_bridge
    def get_active_report_with_encoded_images(self: "Self") -> "str":
        """str"""
        method_result = pythonnet_method_call(
            self.wrapped, "GetActiveReportWithEncodedImages"
        )
        return method_result

    @exception_bridge
    @enforce_parameter_types
    def output_named_report_to(
        self: "Self", report_name: "str", file_path: "PathLike"
    ) -> None:
        """Method does not return.

        Args:
            report_name (str)
            file_path (PathLike)
        """
        report_name = str(report_name)
        file_path = str(file_path)
        pythonnet_method_call(
            self.wrapped,
            "OutputNamedReportTo",
            report_name if report_name else "",
            file_path,
        )

    @exception_bridge
    @enforce_parameter_types
    def output_named_report_as_masta_report(
        self: "Self", report_name: "str", file_path: "PathLike"
    ) -> None:
        """Method does not return.

        Args:
            report_name (str)
            file_path (PathLike)
        """
        report_name = str(report_name)
        file_path = str(file_path)
        pythonnet_method_call(
            self.wrapped,
            "OutputNamedReportAsMastaReport",
            report_name if report_name else "",
            file_path,
        )

    @exception_bridge
    @enforce_parameter_types
    def output_named_report_as_text_to(
        self: "Self", report_name: "str", file_path: "PathLike"
    ) -> None:
        """Method does not return.

        Args:
            report_name (str)
            file_path (PathLike)
        """
        report_name = str(report_name)
        file_path = str(file_path)
        pythonnet_method_call(
            self.wrapped,
            "OutputNamedReportAsTextTo",
            report_name if report_name else "",
            file_path,
        )

    @exception_bridge
    @enforce_parameter_types
    def get_named_report_with_encoded_images(self: "Self", report_name: "str") -> "str":
        """str

        Args:
            report_name (str)
        """
        report_name = str(report_name)
        method_result = pythonnet_method_call(
            self.wrapped,
            "GetNamedReportWithEncodedImages",
            report_name if report_name else "",
        )
        return method_result

    @property
    def cast_to(self: "Self") -> "_Cast_ShaftSectionEndDamageResults":
        """Cast to another type.

        Returns:
            _Cast_ShaftSectionEndDamageResults
        """
        return _Cast_ShaftSectionEndDamageResults(self)



"""Subpackage."""

from typing import TYPE_CHECKING as __tc

if __tc:
    from mastapy._private.electric_machines.load_cases_and_analyses._1558 import (
        BasicDynamicForceLoadCase,
    )
    from mastapy._private.electric_machines.load_cases_and_analyses._1559 import (
        DynamicForceAnalysis,
    )
    from mastapy._private.electric_machines.load_cases_and_analyses._1560 import (
        DynamicForceLoadCase,
    )
    from mastapy._private.electric_machines.load_cases_and_analyses._1561 import (
        DynamicForcesOperatingPoint,
    )
    from mastapy._private.electric_machines.load_cases_and_analyses._1562 import (
        EfficiencyMapAnalysis,
    )
    from mastapy._private.electric_machines.load_cases_and_analyses._1563 import (
        EfficiencyMapLoadCase,
    )
    from mastapy._private.electric_machines.load_cases_and_analyses._1564 import (
        ElectricMachineAnalysis,
    )
    from mastapy._private.electric_machines.load_cases_and_analyses._1565 import (
        ElectricMachineBasicMechanicalLossSettings,
    )
    from mastapy._private.electric_machines.load_cases_and_analyses._1566 import (
        ElectricMachineControlStrategy,
    )
    from mastapy._private.electric_machines.load_cases_and_analyses._1567 import (
        ElectricMachineEfficiencyMapSettings,
    )
    from mastapy._private.electric_machines.load_cases_and_analyses._1568 import (
        ElectricMachineFEAnalysis,
    )
    from mastapy._private.electric_machines.load_cases_and_analyses._1569 import (
        ElectricMachineFEMechanicalAnalysis,
    )
    from mastapy._private.electric_machines.load_cases_and_analyses._1570 import (
        ElectricMachineLoadCase,
    )
    from mastapy._private.electric_machines.load_cases_and_analyses._1571 import (
        ElectricMachineLoadCaseBase,
    )
    from mastapy._private.electric_machines.load_cases_and_analyses._1572 import (
        ElectricMachineLoadCaseGroup,
    )
    from mastapy._private.electric_machines.load_cases_and_analyses._1573 import (
        ElectricMachineMechanicalLoadCase,
    )
    from mastapy._private.electric_machines.load_cases_and_analyses._1574 import (
        EndWindingInductanceMethod,
    )
    from mastapy._private.electric_machines.load_cases_and_analyses._1575 import (
        LeadingOrLagging,
    )
    from mastapy._private.electric_machines.load_cases_and_analyses._1576 import (
        LoadCaseType,
    )
    from mastapy._private.electric_machines.load_cases_and_analyses._1577 import (
        LoadCaseTypeSelector,
    )
    from mastapy._private.electric_machines.load_cases_and_analyses._1578 import (
        MotoringOrGenerating,
    )
    from mastapy._private.electric_machines.load_cases_and_analyses._1579 import (
        NonLinearDQModelMultipleOperatingPointsLoadCase,
    )
    from mastapy._private.electric_machines.load_cases_and_analyses._1580 import (
        NumberOfStepsPerOperatingPointSpecificationMethod,
    )
    from mastapy._private.electric_machines.load_cases_and_analyses._1581 import (
        OperatingPointsSpecificationMethod,
    )
    from mastapy._private.electric_machines.load_cases_and_analyses._1582 import (
        SingleOperatingPointAnalysis,
    )
    from mastapy._private.electric_machines.load_cases_and_analyses._1583 import (
        SlotDetailForAnalysis,
    )
    from mastapy._private.electric_machines.load_cases_and_analyses._1584 import (
        SpecifyTorqueOrCurrent,
    )
    from mastapy._private.electric_machines.load_cases_and_analyses._1585 import (
        SpeedPointsDistribution,
    )
    from mastapy._private.electric_machines.load_cases_and_analyses._1586 import (
        SpeedTorqueCurveAnalysis,
    )
    from mastapy._private.electric_machines.load_cases_and_analyses._1587 import (
        SpeedTorqueCurveLoadCase,
    )
    from mastapy._private.electric_machines.load_cases_and_analyses._1588 import (
        SpeedTorqueLoadCase,
    )
    from mastapy._private.electric_machines.load_cases_and_analyses._1589 import (
        Temperatures,
    )
else:
    import sys as __sys

    from lazy_imports import LazyImporter as __LazyImporter

    __import_structure = {
        "_private.electric_machines.load_cases_and_analyses._1558": [
            "BasicDynamicForceLoadCase"
        ],
        "_private.electric_machines.load_cases_and_analyses._1559": [
            "DynamicForceAnalysis"
        ],
        "_private.electric_machines.load_cases_and_analyses._1560": [
            "DynamicForceLoadCase"
        ],
        "_private.electric_machines.load_cases_and_analyses._1561": [
            "DynamicForcesOperatingPoint"
        ],
        "_private.electric_machines.load_cases_and_analyses._1562": [
            "EfficiencyMapAnalysis"
        ],
        "_private.electric_machines.load_cases_and_analyses._1563": [
            "EfficiencyMapLoadCase"
        ],
        "_private.electric_machines.load_cases_and_analyses._1564": [
            "ElectricMachineAnalysis"
        ],
        "_private.electric_machines.load_cases_and_analyses._1565": [
            "ElectricMachineBasicMechanicalLossSettings"
        ],
        "_private.electric_machines.load_cases_and_analyses._1566": [
            "ElectricMachineControlStrategy"
        ],
        "_private.electric_machines.load_cases_and_analyses._1567": [
            "ElectricMachineEfficiencyMapSettings"
        ],
        "_private.electric_machines.load_cases_and_analyses._1568": [
            "ElectricMachineFEAnalysis"
        ],
        "_private.electric_machines.load_cases_and_analyses._1569": [
            "ElectricMachineFEMechanicalAnalysis"
        ],
        "_private.electric_machines.load_cases_and_analyses._1570": [
            "ElectricMachineLoadCase"
        ],
        "_private.electric_machines.load_cases_and_analyses._1571": [
            "ElectricMachineLoadCaseBase"
        ],
        "_private.electric_machines.load_cases_and_analyses._1572": [
            "ElectricMachineLoadCaseGroup"
        ],
        "_private.electric_machines.load_cases_and_analyses._1573": [
            "ElectricMachineMechanicalLoadCase"
        ],
        "_private.electric_machines.load_cases_and_analyses._1574": [
            "EndWindingInductanceMethod"
        ],
        "_private.electric_machines.load_cases_and_analyses._1575": [
            "LeadingOrLagging"
        ],
        "_private.electric_machines.load_cases_and_analyses._1576": ["LoadCaseType"],
        "_private.electric_machines.load_cases_and_analyses._1577": [
            "LoadCaseTypeSelector"
        ],
        "_private.electric_machines.load_cases_and_analyses._1578": [
            "MotoringOrGenerating"
        ],
        "_private.electric_machines.load_cases_and_analyses._1579": [
            "NonLinearDQModelMultipleOperatingPointsLoadCase"
        ],
        "_private.electric_machines.load_cases_and_analyses._1580": [
            "NumberOfStepsPerOperatingPointSpecificationMethod"
        ],
        "_private.electric_machines.load_cases_and_analyses._1581": [
            "OperatingPointsSpecificationMethod"
        ],
        "_private.electric_machines.load_cases_and_analyses._1582": [
            "SingleOperatingPointAnalysis"
        ],
        "_private.electric_machines.load_cases_and_analyses._1583": [
            "SlotDetailForAnalysis"
        ],
        "_private.electric_machines.load_cases_and_analyses._1584": [
            "SpecifyTorqueOrCurrent"
        ],
        "_private.electric_machines.load_cases_and_analyses._1585": [
            "SpeedPointsDistribution"
        ],
        "_private.electric_machines.load_cases_and_analyses._1586": [
            "SpeedTorqueCurveAnalysis"
        ],
        "_private.electric_machines.load_cases_and_analyses._1587": [
            "SpeedTorqueCurveLoadCase"
        ],
        "_private.electric_machines.load_cases_and_analyses._1588": [
            "SpeedTorqueLoadCase"
        ],
        "_private.electric_machines.load_cases_and_analyses._1589": ["Temperatures"],
    }

    __sys.modules[__name__] = __LazyImporter(
        "mastapy",
        globals()["__file__"],
        __import_structure,
    )

__all__ = (
    "BasicDynamicForceLoadCase",
    "DynamicForceAnalysis",
    "DynamicForceLoadCase",
    "DynamicForcesOperatingPoint",
    "EfficiencyMapAnalysis",
    "EfficiencyMapLoadCase",
    "ElectricMachineAnalysis",
    "ElectricMachineBasicMechanicalLossSettings",
    "ElectricMachineControlStrategy",
    "ElectricMachineEfficiencyMapSettings",
    "ElectricMachineFEAnalysis",
    "ElectricMachineFEMechanicalAnalysis",
    "ElectricMachineLoadCase",
    "ElectricMachineLoadCaseBase",
    "ElectricMachineLoadCaseGroup",
    "ElectricMachineMechanicalLoadCase",
    "EndWindingInductanceMethod",
    "LeadingOrLagging",
    "LoadCaseType",
    "LoadCaseTypeSelector",
    "MotoringOrGenerating",
    "NonLinearDQModelMultipleOperatingPointsLoadCase",
    "NumberOfStepsPerOperatingPointSpecificationMethod",
    "OperatingPointsSpecificationMethod",
    "SingleOperatingPointAnalysis",
    "SlotDetailForAnalysis",
    "SpecifyTorqueOrCurrent",
    "SpeedPointsDistribution",
    "SpeedTorqueCurveAnalysis",
    "SpeedTorqueCurveLoadCase",
    "SpeedTorqueLoadCase",
    "Temperatures",
)



"""Subpackage."""

from typing import TYPE_CHECKING as __tc

if __tc:
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4209 import (
        AbstractAssemblyCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4210 import (
        AbstractShaftCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4211 import (
        AbstractShaftOrHousingCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4212 import (
        AbstractShaftToMountableComponentConnectionCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4213 import (
        AGMAGleasonConicalGearCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4214 import (
        AGMAGleasonConicalGearMeshCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4215 import (
        AGMAGleasonConicalGearSetCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4216 import (
        AssemblyCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4217 import (
        BearingCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4218 import (
        BeltConnectionCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4219 import (
        BeltDriveCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4220 import (
        BevelDifferentialGearCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4221 import (
        BevelDifferentialGearMeshCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4222 import (
        BevelDifferentialGearSetCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4223 import (
        BevelDifferentialPlanetGearCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4224 import (
        BevelDifferentialSunGearCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4225 import (
        BevelGearCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4226 import (
        BevelGearMeshCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4227 import (
        BevelGearSetCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4228 import (
        BoltCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4229 import (
        BoltedJointCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4230 import (
        ClutchCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4231 import (
        ClutchConnectionCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4232 import (
        ClutchHalfCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4233 import (
        CoaxialConnectionCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4234 import (
        ComponentCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4235 import (
        ConceptCouplingCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4236 import (
        ConceptCouplingConnectionCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4237 import (
        ConceptCouplingHalfCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4238 import (
        ConceptGearCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4239 import (
        ConceptGearMeshCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4240 import (
        ConceptGearSetCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4241 import (
        ConicalGearCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4242 import (
        ConicalGearMeshCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4243 import (
        ConicalGearSetCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4244 import (
        ConnectionCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4245 import (
        ConnectorCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4246 import (
        CouplingCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4247 import (
        CouplingConnectionCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4248 import (
        CouplingHalfCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4249 import (
        CVTBeltConnectionCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4250 import (
        CVTCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4251 import (
        CVTPulleyCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4252 import (
        CycloidalAssemblyCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4253 import (
        CycloidalDiscCentralBearingConnectionCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4254 import (
        CycloidalDiscCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4255 import (
        CycloidalDiscPlanetaryBearingConnectionCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4256 import (
        CylindricalGearCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4257 import (
        CylindricalGearMeshCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4258 import (
        CylindricalGearSetCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4259 import (
        CylindricalPlanetGearCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4260 import (
        DatumCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4261 import (
        ExternalCADModelCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4262 import (
        FaceGearCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4263 import (
        FaceGearMeshCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4264 import (
        FaceGearSetCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4265 import (
        FEPartCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4266 import (
        FlexiblePinAssemblyCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4267 import (
        GearCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4268 import (
        GearMeshCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4269 import (
        GearSetCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4270 import (
        GuideDxfModelCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4271 import (
        HypoidGearCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4272 import (
        HypoidGearMeshCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4273 import (
        HypoidGearSetCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4274 import (
        InterMountableComponentConnectionCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4275 import (
        KlingelnbergCycloPalloidConicalGearCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4276 import (
        KlingelnbergCycloPalloidConicalGearMeshCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4277 import (
        KlingelnbergCycloPalloidConicalGearSetCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4278 import (
        KlingelnbergCycloPalloidHypoidGearCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4279 import (
        KlingelnbergCycloPalloidHypoidGearMeshCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4280 import (
        KlingelnbergCycloPalloidHypoidGearSetCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4281 import (
        KlingelnbergCycloPalloidSpiralBevelGearCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4282 import (
        KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4283 import (
        KlingelnbergCycloPalloidSpiralBevelGearSetCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4284 import (
        MassDiscCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4285 import (
        MeasurementComponentCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4286 import (
        MicrophoneArrayCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4287 import (
        MicrophoneCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4288 import (
        MountableComponentCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4289 import (
        OilSealCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4290 import (
        PartCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4291 import (
        PartToPartShearCouplingCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4292 import (
        PartToPartShearCouplingConnectionCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4293 import (
        PartToPartShearCouplingHalfCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4294 import (
        PlanetaryConnectionCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4295 import (
        PlanetaryGearSetCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4296 import (
        PlanetCarrierCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4297 import (
        PointLoadCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4298 import (
        PowerLoadCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4299 import (
        PulleyCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4300 import (
        RingPinsCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4301 import (
        RingPinsToDiscConnectionCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4302 import (
        RollingRingAssemblyCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4303 import (
        RollingRingCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4304 import (
        RollingRingConnectionCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4305 import (
        RootAssemblyCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4306 import (
        ShaftCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4307 import (
        ShaftHubConnectionCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4308 import (
        ShaftToMountableComponentConnectionCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4309 import (
        SpecialisedAssemblyCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4310 import (
        SpiralBevelGearCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4311 import (
        SpiralBevelGearMeshCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4312 import (
        SpiralBevelGearSetCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4313 import (
        SpringDamperCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4314 import (
        SpringDamperConnectionCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4315 import (
        SpringDamperHalfCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4316 import (
        StraightBevelDiffGearCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4317 import (
        StraightBevelDiffGearMeshCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4318 import (
        StraightBevelDiffGearSetCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4319 import (
        StraightBevelGearCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4320 import (
        StraightBevelGearMeshCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4321 import (
        StraightBevelGearSetCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4322 import (
        StraightBevelPlanetGearCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4323 import (
        StraightBevelSunGearCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4324 import (
        SynchroniserCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4325 import (
        SynchroniserHalfCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4326 import (
        SynchroniserPartCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4327 import (
        SynchroniserSleeveCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4328 import (
        TorqueConverterCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4329 import (
        TorqueConverterConnectionCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4330 import (
        TorqueConverterPumpCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4331 import (
        TorqueConverterTurbineCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4332 import (
        UnbalancedMassCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4333 import (
        VirtualComponentCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4334 import (
        WormGearCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4335 import (
        WormGearMeshCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4336 import (
        WormGearSetCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4337 import (
        ZerolBevelGearCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4338 import (
        ZerolBevelGearMeshCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4339 import (
        ZerolBevelGearSetCompoundStabilityAnalysis,
    )
else:
    import sys as __sys

    from lazy_imports import LazyImporter as __LazyImporter

    __import_structure = {
        "_private.system_model.analyses_and_results.stability_analyses.compound._4209": [
            "AbstractAssemblyCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4210": [
            "AbstractShaftCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4211": [
            "AbstractShaftOrHousingCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4212": [
            "AbstractShaftToMountableComponentConnectionCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4213": [
            "AGMAGleasonConicalGearCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4214": [
            "AGMAGleasonConicalGearMeshCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4215": [
            "AGMAGleasonConicalGearSetCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4216": [
            "AssemblyCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4217": [
            "BearingCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4218": [
            "BeltConnectionCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4219": [
            "BeltDriveCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4220": [
            "BevelDifferentialGearCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4221": [
            "BevelDifferentialGearMeshCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4222": [
            "BevelDifferentialGearSetCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4223": [
            "BevelDifferentialPlanetGearCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4224": [
            "BevelDifferentialSunGearCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4225": [
            "BevelGearCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4226": [
            "BevelGearMeshCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4227": [
            "BevelGearSetCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4228": [
            "BoltCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4229": [
            "BoltedJointCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4230": [
            "ClutchCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4231": [
            "ClutchConnectionCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4232": [
            "ClutchHalfCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4233": [
            "CoaxialConnectionCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4234": [
            "ComponentCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4235": [
            "ConceptCouplingCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4236": [
            "ConceptCouplingConnectionCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4237": [
            "ConceptCouplingHalfCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4238": [
            "ConceptGearCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4239": [
            "ConceptGearMeshCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4240": [
            "ConceptGearSetCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4241": [
            "ConicalGearCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4242": [
            "ConicalGearMeshCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4243": [
            "ConicalGearSetCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4244": [
            "ConnectionCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4245": [
            "ConnectorCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4246": [
            "CouplingCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4247": [
            "CouplingConnectionCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4248": [
            "CouplingHalfCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4249": [
            "CVTBeltConnectionCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4250": [
            "CVTCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4251": [
            "CVTPulleyCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4252": [
            "CycloidalAssemblyCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4253": [
            "CycloidalDiscCentralBearingConnectionCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4254": [
            "CycloidalDiscCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4255": [
            "CycloidalDiscPlanetaryBearingConnectionCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4256": [
            "CylindricalGearCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4257": [
            "CylindricalGearMeshCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4258": [
            "CylindricalGearSetCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4259": [
            "CylindricalPlanetGearCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4260": [
            "DatumCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4261": [
            "ExternalCADModelCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4262": [
            "FaceGearCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4263": [
            "FaceGearMeshCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4264": [
            "FaceGearSetCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4265": [
            "FEPartCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4266": [
            "FlexiblePinAssemblyCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4267": [
            "GearCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4268": [
            "GearMeshCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4269": [
            "GearSetCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4270": [
            "GuideDxfModelCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4271": [
            "HypoidGearCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4272": [
            "HypoidGearMeshCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4273": [
            "HypoidGearSetCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4274": [
            "InterMountableComponentConnectionCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4275": [
            "KlingelnbergCycloPalloidConicalGearCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4276": [
            "KlingelnbergCycloPalloidConicalGearMeshCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4277": [
            "KlingelnbergCycloPalloidConicalGearSetCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4278": [
            "KlingelnbergCycloPalloidHypoidGearCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4279": [
            "KlingelnbergCycloPalloidHypoidGearMeshCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4280": [
            "KlingelnbergCycloPalloidHypoidGearSetCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4281": [
            "KlingelnbergCycloPalloidSpiralBevelGearCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4282": [
            "KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4283": [
            "KlingelnbergCycloPalloidSpiralBevelGearSetCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4284": [
            "MassDiscCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4285": [
            "MeasurementComponentCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4286": [
            "MicrophoneArrayCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4287": [
            "MicrophoneCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4288": [
            "MountableComponentCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4289": [
            "OilSealCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4290": [
            "PartCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4291": [
            "PartToPartShearCouplingCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4292": [
            "PartToPartShearCouplingConnectionCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4293": [
            "PartToPartShearCouplingHalfCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4294": [
            "PlanetaryConnectionCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4295": [
            "PlanetaryGearSetCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4296": [
            "PlanetCarrierCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4297": [
            "PointLoadCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4298": [
            "PowerLoadCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4299": [
            "PulleyCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4300": [
            "RingPinsCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4301": [
            "RingPinsToDiscConnectionCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4302": [
            "RollingRingAssemblyCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4303": [
            "RollingRingCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4304": [
            "RollingRingConnectionCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4305": [
            "RootAssemblyCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4306": [
            "ShaftCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4307": [
            "ShaftHubConnectionCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4308": [
            "ShaftToMountableComponentConnectionCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4309": [
            "SpecialisedAssemblyCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4310": [
            "SpiralBevelGearCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4311": [
            "SpiralBevelGearMeshCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4312": [
            "SpiralBevelGearSetCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4313": [
            "SpringDamperCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4314": [
            "SpringDamperConnectionCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4315": [
            "SpringDamperHalfCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4316": [
            "StraightBevelDiffGearCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4317": [
            "StraightBevelDiffGearMeshCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4318": [
            "StraightBevelDiffGearSetCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4319": [
            "StraightBevelGearCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4320": [
            "StraightBevelGearMeshCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4321": [
            "StraightBevelGearSetCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4322": [
            "StraightBevelPlanetGearCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4323": [
            "StraightBevelSunGearCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4324": [
            "SynchroniserCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4325": [
            "SynchroniserHalfCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4326": [
            "SynchroniserPartCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4327": [
            "SynchroniserSleeveCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4328": [
            "TorqueConverterCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4329": [
            "TorqueConverterConnectionCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4330": [
            "TorqueConverterPumpCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4331": [
            "TorqueConverterTurbineCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4332": [
            "UnbalancedMassCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4333": [
            "VirtualComponentCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4334": [
            "WormGearCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4335": [
            "WormGearMeshCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4336": [
            "WormGearSetCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4337": [
            "ZerolBevelGearCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4338": [
            "ZerolBevelGearMeshCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4339": [
            "ZerolBevelGearSetCompoundStabilityAnalysis"
        ],
    }

    __sys.modules[__name__] = __LazyImporter(
        "mastapy",
        globals()["__file__"],
        __import_structure,
    )

__all__ = (
    "AbstractAssemblyCompoundStabilityAnalysis",
    "AbstractShaftCompoundStabilityAnalysis",
    "AbstractShaftOrHousingCompoundStabilityAnalysis",
    "AbstractShaftToMountableComponentConnectionCompoundStabilityAnalysis",
    "AGMAGleasonConicalGearCompoundStabilityAnalysis",
    "AGMAGleasonConicalGearMeshCompoundStabilityAnalysis",
    "AGMAGleasonConicalGearSetCompoundStabilityAnalysis",
    "AssemblyCompoundStabilityAnalysis",
    "BearingCompoundStabilityAnalysis",
    "BeltConnectionCompoundStabilityAnalysis",
    "BeltDriveCompoundStabilityAnalysis",
    "BevelDifferentialGearCompoundStabilityAnalysis",
    "BevelDifferentialGearMeshCompoundStabilityAnalysis",
    "BevelDifferentialGearSetCompoundStabilityAnalysis",
    "BevelDifferentialPlanetGearCompoundStabilityAnalysis",
    "BevelDifferentialSunGearCompoundStabilityAnalysis",
    "BevelGearCompoundStabilityAnalysis",
    "BevelGearMeshCompoundStabilityAnalysis",
    "BevelGearSetCompoundStabilityAnalysis",
    "BoltCompoundStabilityAnalysis",
    "BoltedJointCompoundStabilityAnalysis",
    "ClutchCompoundStabilityAnalysis",
    "ClutchConnectionCompoundStabilityAnalysis",
    "ClutchHalfCompoundStabilityAnalysis",
    "CoaxialConnectionCompoundStabilityAnalysis",
    "ComponentCompoundStabilityAnalysis",
    "ConceptCouplingCompoundStabilityAnalysis",
    "ConceptCouplingConnectionCompoundStabilityAnalysis",
    "ConceptCouplingHalfCompoundStabilityAnalysis",
    "ConceptGearCompoundStabilityAnalysis",
    "ConceptGearMeshCompoundStabilityAnalysis",
    "ConceptGearSetCompoundStabilityAnalysis",
    "ConicalGearCompoundStabilityAnalysis",
    "ConicalGearMeshCompoundStabilityAnalysis",
    "ConicalGearSetCompoundStabilityAnalysis",
    "ConnectionCompoundStabilityAnalysis",
    "ConnectorCompoundStabilityAnalysis",
    "CouplingCompoundStabilityAnalysis",
    "CouplingConnectionCompoundStabilityAnalysis",
    "CouplingHalfCompoundStabilityAnalysis",
    "CVTBeltConnectionCompoundStabilityAnalysis",
    "CVTCompoundStabilityAnalysis",
    "CVTPulleyCompoundStabilityAnalysis",
    "CycloidalAssemblyCompoundStabilityAnalysis",
    "CycloidalDiscCentralBearingConnectionCompoundStabilityAnalysis",
    "CycloidalDiscCompoundStabilityAnalysis",
    "CycloidalDiscPlanetaryBearingConnectionCompoundStabilityAnalysis",
    "CylindricalGearCompoundStabilityAnalysis",
    "CylindricalGearMeshCompoundStabilityAnalysis",
    "CylindricalGearSetCompoundStabilityAnalysis",
    "CylindricalPlanetGearCompoundStabilityAnalysis",
    "DatumCompoundStabilityAnalysis",
    "ExternalCADModelCompoundStabilityAnalysis",
    "FaceGearCompoundStabilityAnalysis",
    "FaceGearMeshCompoundStabilityAnalysis",
    "FaceGearSetCompoundStabilityAnalysis",
    "FEPartCompoundStabilityAnalysis",
    "FlexiblePinAssemblyCompoundStabilityAnalysis",
    "GearCompoundStabilityAnalysis",
    "GearMeshCompoundStabilityAnalysis",
    "GearSetCompoundStabilityAnalysis",
    "GuideDxfModelCompoundStabilityAnalysis",
    "HypoidGearCompoundStabilityAnalysis",
    "HypoidGearMeshCompoundStabilityAnalysis",
    "HypoidGearSetCompoundStabilityAnalysis",
    "InterMountableComponentConnectionCompoundStabilityAnalysis",
    "KlingelnbergCycloPalloidConicalGearCompoundStabilityAnalysis",
    "KlingelnbergCycloPalloidConicalGearMeshCompoundStabilityAnalysis",
    "KlingelnbergCycloPalloidConicalGearSetCompoundStabilityAnalysis",
    "KlingelnbergCycloPalloidHypoidGearCompoundStabilityAnalysis",
    "KlingelnbergCycloPalloidHypoidGearMeshCompoundStabilityAnalysis",
    "KlingelnbergCycloPalloidHypoidGearSetCompoundStabilityAnalysis",
    "KlingelnbergCycloPalloidSpiralBevelGearCompoundStabilityAnalysis",
    "KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundStabilityAnalysis",
    "KlingelnbergCycloPalloidSpiralBevelGearSetCompoundStabilityAnalysis",
    "MassDiscCompoundStabilityAnalysis",
    "MeasurementComponentCompoundStabilityAnalysis",
    "MicrophoneArrayCompoundStabilityAnalysis",
    "MicrophoneCompoundStabilityAnalysis",
    "MountableComponentCompoundStabilityAnalysis",
    "OilSealCompoundStabilityAnalysis",
    "PartCompoundStabilityAnalysis",
    "PartToPartShearCouplingCompoundStabilityAnalysis",
    "PartToPartShearCouplingConnectionCompoundStabilityAnalysis",
    "PartToPartShearCouplingHalfCompoundStabilityAnalysis",
    "PlanetaryConnectionCompoundStabilityAnalysis",
    "PlanetaryGearSetCompoundStabilityAnalysis",
    "PlanetCarrierCompoundStabilityAnalysis",
    "PointLoadCompoundStabilityAnalysis",
    "PowerLoadCompoundStabilityAnalysis",
    "PulleyCompoundStabilityAnalysis",
    "RingPinsCompoundStabilityAnalysis",
    "RingPinsToDiscConnectionCompoundStabilityAnalysis",
    "RollingRingAssemblyCompoundStabilityAnalysis",
    "RollingRingCompoundStabilityAnalysis",
    "RollingRingConnectionCompoundStabilityAnalysis",
    "RootAssemblyCompoundStabilityAnalysis",
    "ShaftCompoundStabilityAnalysis",
    "ShaftHubConnectionCompoundStabilityAnalysis",
    "ShaftToMountableComponentConnectionCompoundStabilityAnalysis",
    "SpecialisedAssemblyCompoundStabilityAnalysis",
    "SpiralBevelGearCompoundStabilityAnalysis",
    "SpiralBevelGearMeshCompoundStabilityAnalysis",
    "SpiralBevelGearSetCompoundStabilityAnalysis",
    "SpringDamperCompoundStabilityAnalysis",
    "SpringDamperConnectionCompoundStabilityAnalysis",
    "SpringDamperHalfCompoundStabilityAnalysis",
    "StraightBevelDiffGearCompoundStabilityAnalysis",
    "StraightBevelDiffGearMeshCompoundStabilityAnalysis",
    "StraightBevelDiffGearSetCompoundStabilityAnalysis",
    "StraightBevelGearCompoundStabilityAnalysis",
    "StraightBevelGearMeshCompoundStabilityAnalysis",
    "StraightBevelGearSetCompoundStabilityAnalysis",
    "StraightBevelPlanetGearCompoundStabilityAnalysis",
    "StraightBevelSunGearCompoundStabilityAnalysis",
    "SynchroniserCompoundStabilityAnalysis",
    "SynchroniserHalfCompoundStabilityAnalysis",
    "SynchroniserPartCompoundStabilityAnalysis",
    "SynchroniserSleeveCompoundStabilityAnalysis",
    "TorqueConverterCompoundStabilityAnalysis",
    "TorqueConverterConnectionCompoundStabilityAnalysis",
    "TorqueConverterPumpCompoundStabilityAnalysis",
    "TorqueConverterTurbineCompoundStabilityAnalysis",
    "UnbalancedMassCompoundStabilityAnalysis",
    "VirtualComponentCompoundStabilityAnalysis",
    "WormGearCompoundStabilityAnalysis",
    "WormGearMeshCompoundStabilityAnalysis",
    "WormGearSetCompoundStabilityAnalysis",
    "ZerolBevelGearCompoundStabilityAnalysis",
    "ZerolBevelGearMeshCompoundStabilityAnalysis",
    "ZerolBevelGearSetCompoundStabilityAnalysis",
)



"""AbstractShaftOrHousingCompoundSteadyStateSynchronousResponseAtASpeed"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_property_get,
)

from mastapy._private._internal import conversion, utility
from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed.compound import (
    _3967,
)

_ABSTRACT_SHAFT_OR_HOUSING_COMPOUND_STEADY_STATE_SYNCHRONOUS_RESPONSE_AT_A_SPEED = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.SteadyStateSynchronousResponsesAtASpeed.Compound",
    "AbstractShaftOrHousingCompoundSteadyStateSynchronousResponseAtASpeed",
)

if TYPE_CHECKING:
    from typing import Any, List, Type, TypeVar

    from mastapy._private.system_model.analyses_and_results import _2944
    from mastapy._private.system_model.analyses_and_results.analysis_cases import (
        _7941,
        _7944,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed import (
        _3811,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed.compound import (
        _3943,
        _3987,
        _3998,
        _4023,
        _4039,
    )

    Self = TypeVar(
        "Self",
        bound="AbstractShaftOrHousingCompoundSteadyStateSynchronousResponseAtASpeed",
    )
    CastSelf = TypeVar(
        "CastSelf",
        bound="AbstractShaftOrHousingCompoundSteadyStateSynchronousResponseAtASpeed._Cast_AbstractShaftOrHousingCompoundSteadyStateSynchronousResponseAtASpeed",
    )


__docformat__ = "restructuredtext en"
__all__ = ("AbstractShaftOrHousingCompoundSteadyStateSynchronousResponseAtASpeed",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_AbstractShaftOrHousingCompoundSteadyStateSynchronousResponseAtASpeed:
    """Special nested class for casting AbstractShaftOrHousingCompoundSteadyStateSynchronousResponseAtASpeed to subclasses."""

    __parent__: "AbstractShaftOrHousingCompoundSteadyStateSynchronousResponseAtASpeed"

    @property
    def component_compound_steady_state_synchronous_response_at_a_speed(
        self: "CastSelf",
    ) -> "_3967.ComponentCompoundSteadyStateSynchronousResponseAtASpeed":
        return self.__parent__._cast(
            _3967.ComponentCompoundSteadyStateSynchronousResponseAtASpeed
        )

    @property
    def part_compound_steady_state_synchronous_response_at_a_speed(
        self: "CastSelf",
    ) -> "_4023.PartCompoundSteadyStateSynchronousResponseAtASpeed":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed.compound import (
            _4023,
        )

        return self.__parent__._cast(
            _4023.PartCompoundSteadyStateSynchronousResponseAtASpeed
        )

    @property
    def part_compound_analysis(self: "CastSelf") -> "_7944.PartCompoundAnalysis":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7944,
        )

        return self.__parent__._cast(_7944.PartCompoundAnalysis)

    @property
    def design_entity_compound_analysis(
        self: "CastSelf",
    ) -> "_7941.DesignEntityCompoundAnalysis":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7941,
        )

        return self.__parent__._cast(_7941.DesignEntityCompoundAnalysis)

    @property
    def design_entity_analysis(self: "CastSelf") -> "_2944.DesignEntityAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2944

        return self.__parent__._cast(_2944.DesignEntityAnalysis)

    @property
    def abstract_shaft_compound_steady_state_synchronous_response_at_a_speed(
        self: "CastSelf",
    ) -> "_3943.AbstractShaftCompoundSteadyStateSynchronousResponseAtASpeed":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed.compound import (
            _3943,
        )

        return self.__parent__._cast(
            _3943.AbstractShaftCompoundSteadyStateSynchronousResponseAtASpeed
        )

    @property
    def cycloidal_disc_compound_steady_state_synchronous_response_at_a_speed(
        self: "CastSelf",
    ) -> "_3987.CycloidalDiscCompoundSteadyStateSynchronousResponseAtASpeed":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed.compound import (
            _3987,
        )

        return self.__parent__._cast(
            _3987.CycloidalDiscCompoundSteadyStateSynchronousResponseAtASpeed
        )

    @property
    def fe_part_compound_steady_state_synchronous_response_at_a_speed(
        self: "CastSelf",
    ) -> "_3998.FEPartCompoundSteadyStateSynchronousResponseAtASpeed":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed.compound import (
            _3998,
        )

        return self.__parent__._cast(
            _3998.FEPartCompoundSteadyStateSynchronousResponseAtASpeed
        )

    @property
    def shaft_compound_steady_state_synchronous_response_at_a_speed(
        self: "CastSelf",
    ) -> "_4039.ShaftCompoundSteadyStateSynchronousResponseAtASpeed":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed.compound import (
            _4039,
        )

        return self.__parent__._cast(
            _4039.ShaftCompoundSteadyStateSynchronousResponseAtASpeed
        )

    @property
    def abstract_shaft_or_housing_compound_steady_state_synchronous_response_at_a_speed(
        self: "CastSelf",
    ) -> "AbstractShaftOrHousingCompoundSteadyStateSynchronousResponseAtASpeed":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class AbstractShaftOrHousingCompoundSteadyStateSynchronousResponseAtASpeed(
    _3967.ComponentCompoundSteadyStateSynchronousResponseAtASpeed
):
    """AbstractShaftOrHousingCompoundSteadyStateSynchronousResponseAtASpeed

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = (
        _ABSTRACT_SHAFT_OR_HOUSING_COMPOUND_STEADY_STATE_SYNCHRONOUS_RESPONSE_AT_A_SPEED
    )

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def component_analysis_cases(
        self: "Self",
    ) -> "List[_3811.AbstractShaftOrHousingSteadyStateSynchronousResponseAtASpeed]":
        """List[mastapy.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed.AbstractShaftOrHousingSteadyStateSynchronousResponseAtASpeed]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ComponentAnalysisCases")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def component_analysis_cases_ready(
        self: "Self",
    ) -> "List[_3811.AbstractShaftOrHousingSteadyStateSynchronousResponseAtASpeed]":
        """List[mastapy.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed.AbstractShaftOrHousingSteadyStateSynchronousResponseAtASpeed]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ComponentAnalysisCasesReady")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def cast_to(
        self: "Self",
    ) -> "_Cast_AbstractShaftOrHousingCompoundSteadyStateSynchronousResponseAtASpeed":
        """Cast to another type.

        Returns:
            _Cast_AbstractShaftOrHousingCompoundSteadyStateSynchronousResponseAtASpeed
        """
        return (
            _Cast_AbstractShaftOrHousingCompoundSteadyStateSynchronousResponseAtASpeed(
                self
            )
        )



"""LoadedPlainOilFedJournalBearing"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_property_get,
)

from mastapy._private._internal import utility
from mastapy._private.bearings.bearing_results.fluid_film import _2370

_LOADED_PLAIN_OIL_FED_JOURNAL_BEARING = python_net_import(
    "SMT.MastaAPI.Bearings.BearingResults.FluidFilm", "LoadedPlainOilFedJournalBearing"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.bearings import _2114
    from mastapy._private.bearings.bearing_results import _2190, _2195, _2198
    from mastapy._private.bearings.bearing_results.fluid_film import _2367

    Self = TypeVar("Self", bound="LoadedPlainOilFedJournalBearing")
    CastSelf = TypeVar(
        "CastSelf",
        bound="LoadedPlainOilFedJournalBearing._Cast_LoadedPlainOilFedJournalBearing",
    )


__docformat__ = "restructuredtext en"
__all__ = ("LoadedPlainOilFedJournalBearing",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_LoadedPlainOilFedJournalBearing:
    """Special nested class for casting LoadedPlainOilFedJournalBearing to subclasses."""

    __parent__: "LoadedPlainOilFedJournalBearing"

    @property
    def loaded_plain_journal_bearing_results(
        self: "CastSelf",
    ) -> "_2370.LoadedPlainJournalBearingResults":
        return self.__parent__._cast(_2370.LoadedPlainJournalBearingResults)

    @property
    def loaded_fluid_film_bearing_results(
        self: "CastSelf",
    ) -> "_2367.LoadedFluidFilmBearingResults":
        from mastapy._private.bearings.bearing_results.fluid_film import _2367

        return self.__parent__._cast(_2367.LoadedFluidFilmBearingResults)

    @property
    def loaded_detailed_bearing_results(
        self: "CastSelf",
    ) -> "_2195.LoadedDetailedBearingResults":
        from mastapy._private.bearings.bearing_results import _2195

        return self.__parent__._cast(_2195.LoadedDetailedBearingResults)

    @property
    def loaded_non_linear_bearing_results(
        self: "CastSelf",
    ) -> "_2198.LoadedNonLinearBearingResults":
        from mastapy._private.bearings.bearing_results import _2198

        return self.__parent__._cast(_2198.LoadedNonLinearBearingResults)

    @property
    def loaded_bearing_results(self: "CastSelf") -> "_2190.LoadedBearingResults":
        from mastapy._private.bearings.bearing_results import _2190

        return self.__parent__._cast(_2190.LoadedBearingResults)

    @property
    def bearing_load_case_results_lightweight(
        self: "CastSelf",
    ) -> "_2114.BearingLoadCaseResultsLightweight":
        from mastapy._private.bearings import _2114

        return self.__parent__._cast(_2114.BearingLoadCaseResultsLightweight)

    @property
    def loaded_plain_oil_fed_journal_bearing(
        self: "CastSelf",
    ) -> "LoadedPlainOilFedJournalBearing":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class LoadedPlainOilFedJournalBearing(_2370.LoadedPlainJournalBearingResults):
    """LoadedPlainOilFedJournalBearing

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _LOADED_PLAIN_OIL_FED_JOURNAL_BEARING

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def angle_between_oil_feed_inlet_and_minimum_film_thickness(
        self: "Self",
    ) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "AngleBetweenOilFeedInletAndMinimumFilmThickness"
        )

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def angle_between_oil_feed_inlet_and_point_of_loading(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "AngleBetweenOilFeedInletAndPointOfLoading"
        )

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def combined_flow_rate(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "CombinedFlowRate")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def current_oil_inlet_angular_position_from_the_x_axis(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "CurrentOilInletAngularPositionFromTheXAxis"
        )

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def feed_pressure(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "FeedPressure")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def ideal_oil_inlet_angular_position_from_the_x_axis(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "IdealOilInletAngularPositionFromTheXAxis"
        )

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def oil_exit_temperature(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "OilExitTemperature")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def pressure_flow_rate(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "PressureFlowRate")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def side_flow_rate(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "SideFlowRate")

        if temp is None:
            return 0.0

        return temp

    @property
    def cast_to(self: "Self") -> "_Cast_LoadedPlainOilFedJournalBearing":
        """Cast to another type.

        Returns:
            _Cast_LoadedPlainOilFedJournalBearing
        """
        return _Cast_LoadedPlainOilFedJournalBearing(self)



"""Subpackage."""

from typing import TYPE_CHECKING as __tc

if __tc:
    from mastapy._private.system_model.connections_and_sockets._2525 import (
        AbstractShaftToMountableComponentConnection,
    )
    from mastapy._private.system_model.connections_and_sockets._2526 import (
        BearingInnerSocket,
    )
    from mastapy._private.system_model.connections_and_sockets._2527 import (
        BearingOuterSocket,
    )
    from mastapy._private.system_model.connections_and_sockets._2528 import (
        BeltConnection,
    )
    from mastapy._private.system_model.connections_and_sockets._2529 import (
        CoaxialConnection,
    )
    from mastapy._private.system_model.connections_and_sockets._2530 import (
        ComponentConnection,
    )
    from mastapy._private.system_model.connections_and_sockets._2531 import (
        ComponentMeasurer,
    )
    from mastapy._private.system_model.connections_and_sockets._2532 import Connection
    from mastapy._private.system_model.connections_and_sockets._2533 import (
        CVTBeltConnection,
    )
    from mastapy._private.system_model.connections_and_sockets._2534 import (
        CVTPulleySocket,
    )
    from mastapy._private.system_model.connections_and_sockets._2535 import (
        CylindricalComponentConnection,
    )
    from mastapy._private.system_model.connections_and_sockets._2536 import (
        CylindricalSocket,
    )
    from mastapy._private.system_model.connections_and_sockets._2537 import (
        DatumMeasurement,
    )
    from mastapy._private.system_model.connections_and_sockets._2538 import (
        ElectricMachineStatorSocket,
    )
    from mastapy._private.system_model.connections_and_sockets._2539 import (
        InnerShaftSocket,
    )
    from mastapy._private.system_model.connections_and_sockets._2540 import (
        InnerShaftSocketBase,
    )
    from mastapy._private.system_model.connections_and_sockets._2541 import (
        InterMountableComponentConnection,
    )
    from mastapy._private.system_model.connections_and_sockets._2542 import (
        MountableComponentInnerSocket,
    )
    from mastapy._private.system_model.connections_and_sockets._2543 import (
        MountableComponentOuterSocket,
    )
    from mastapy._private.system_model.connections_and_sockets._2544 import (
        MountableComponentSocket,
    )
    from mastapy._private.system_model.connections_and_sockets._2545 import (
        OuterShaftSocket,
    )
    from mastapy._private.system_model.connections_and_sockets._2546 import (
        OuterShaftSocketBase,
    )
    from mastapy._private.system_model.connections_and_sockets._2547 import (
        PlanetaryConnection,
    )
    from mastapy._private.system_model.connections_and_sockets._2548 import (
        PlanetarySocket,
    )
    from mastapy._private.system_model.connections_and_sockets._2549 import (
        PlanetarySocketBase,
    )
    from mastapy._private.system_model.connections_and_sockets._2550 import PulleySocket
    from mastapy._private.system_model.connections_and_sockets._2551 import (
        RealignmentResult,
    )
    from mastapy._private.system_model.connections_and_sockets._2552 import (
        RollingRingConnection,
    )
    from mastapy._private.system_model.connections_and_sockets._2553 import (
        RollingRingSocket,
    )
    from mastapy._private.system_model.connections_and_sockets._2554 import ShaftSocket
    from mastapy._private.system_model.connections_and_sockets._2555 import (
        ShaftToMountableComponentConnection,
    )
    from mastapy._private.system_model.connections_and_sockets._2556 import Socket
    from mastapy._private.system_model.connections_and_sockets._2557 import (
        SocketConnectionOptions,
    )
    from mastapy._private.system_model.connections_and_sockets._2558 import (
        SocketConnectionSelection,
    )
else:
    import sys as __sys

    from lazy_imports import LazyImporter as __LazyImporter

    __import_structure = {
        "_private.system_model.connections_and_sockets._2525": [
            "AbstractShaftToMountableComponentConnection"
        ],
        "_private.system_model.connections_and_sockets._2526": ["BearingInnerSocket"],
        "_private.system_model.connections_and_sockets._2527": ["BearingOuterSocket"],
        "_private.system_model.connections_and_sockets._2528": ["BeltConnection"],
        "_private.system_model.connections_and_sockets._2529": ["CoaxialConnection"],
        "_private.system_model.connections_and_sockets._2530": ["ComponentConnection"],
        "_private.system_model.connections_and_sockets._2531": ["ComponentMeasurer"],
        "_private.system_model.connections_and_sockets._2532": ["Connection"],
        "_private.system_model.connections_and_sockets._2533": ["CVTBeltConnection"],
        "_private.system_model.connections_and_sockets._2534": ["CVTPulleySocket"],
        "_private.system_model.connections_and_sockets._2535": [
            "CylindricalComponentConnection"
        ],
        "_private.system_model.connections_and_sockets._2536": ["CylindricalSocket"],
        "_private.system_model.connections_and_sockets._2537": ["DatumMeasurement"],
        "_private.system_model.connections_and_sockets._2538": [
            "ElectricMachineStatorSocket"
        ],
        "_private.system_model.connections_and_sockets._2539": ["InnerShaftSocket"],
        "_private.system_model.connections_and_sockets._2540": ["InnerShaftSocketBase"],
        "_private.system_model.connections_and_sockets._2541": [
            "InterMountableComponentConnection"
        ],
        "_private.system_model.connections_and_sockets._2542": [
            "MountableComponentInnerSocket"
        ],
        "_private.system_model.connections_and_sockets._2543": [
            "MountableComponentOuterSocket"
        ],
        "_private.system_model.connections_and_sockets._2544": [
            "MountableComponentSocket"
        ],
        "_private.system_model.connections_and_sockets._2545": ["OuterShaftSocket"],
        "_private.system_model.connections_and_sockets._2546": ["OuterShaftSocketBase"],
        "_private.system_model.connections_and_sockets._2547": ["PlanetaryConnection"],
        "_private.system_model.connections_and_sockets._2548": ["PlanetarySocket"],
        "_private.system_model.connections_and_sockets._2549": ["PlanetarySocketBase"],
        "_private.system_model.connections_and_sockets._2550": ["PulleySocket"],
        "_private.system_model.connections_and_sockets._2551": ["RealignmentResult"],
        "_private.system_model.connections_and_sockets._2552": [
            "RollingRingConnection"
        ],
        "_private.system_model.connections_and_sockets._2553": ["RollingRingSocket"],
        "_private.system_model.connections_and_sockets._2554": ["ShaftSocket"],
        "_private.system_model.connections_and_sockets._2555": [
            "ShaftToMountableComponentConnection"
        ],
        "_private.system_model.connections_and_sockets._2556": ["Socket"],
        "_private.system_model.connections_and_sockets._2557": [
            "SocketConnectionOptions"
        ],
        "_private.system_model.connections_and_sockets._2558": [
            "SocketConnectionSelection"
        ],
    }

    __sys.modules[__name__] = __LazyImporter(
        "mastapy",
        globals()["__file__"],
        __import_structure,
    )

__all__ = (
    "AbstractShaftToMountableComponentConnection",
    "BearingInnerSocket",
    "BearingOuterSocket",
    "BeltConnection",
    "CoaxialConnection",
    "ComponentConnection",
    "ComponentMeasurer",
    "Connection",
    "CVTBeltConnection",
    "CVTPulleySocket",
    "CylindricalComponentConnection",
    "CylindricalSocket",
    "DatumMeasurement",
    "ElectricMachineStatorSocket",
    "InnerShaftSocket",
    "InnerShaftSocketBase",
    "InterMountableComponentConnection",
    "MountableComponentInnerSocket",
    "MountableComponentOuterSocket",
    "MountableComponentSocket",
    "OuterShaftSocket",
    "OuterShaftSocketBase",
    "PlanetaryConnection",
    "PlanetarySocket",
    "PlanetarySocketBase",
    "PulleySocket",
    "RealignmentResult",
    "RollingRingConnection",
    "RollingRingSocket",
    "ShaftSocket",
    "ShaftToMountableComponentConnection",
    "Socket",
    "SocketConnectionOptions",
    "SocketConnectionSelection",
)
